Collection

Struct Collection 

pub struct Collection {
    pub name: Option<String>,
    pub profiles: IndexMap<ProfileId, Profile>,
    pub recipes: RecipeTree,
}
A collection of profiles, requests, etc. This is the primary Slumber unit of configuration.

Fields

name: Option<String>

Descriptive name for the collection

profiles: IndexMap<ProfileId, Profile>

Map of profiles, keyed by their unique IDs

recipes: RecipeTree

Map of requests and folders, keyed by their unique IDs. Folders allow for nested maps of more requests and folders. All IDs must be unique throughout the entire tree, not just at their level.

Implementations

Source

impl Collection

pub fn load(path: &Path) -> Result<Self, CollectionError>

Load collection from a file

pub fn parse(input: &str) -> Result<Self, CollectionError>

Load collection from a YAML string

Source

impl Collection

pub fn default_profile(&self) -> Option<&Profile>

Get the profile marked as default: true, if any. At most one profile can be marked as default.