DatabaseError

Enum DatabaseError 

pub enum DatabaseError {
    Context {
        context: String,
        error: Box<Self>,
    },
    Directory(Error),
    Migrate(Error),
    Path {
        path: PathBuf,
        error: Error,
    },
    ResourceUnknown {
        kind: &'static str,
        id: String,
    },
    Sqlite(Error),
}
Any error that can occur while accessing the local database

Variants



Context

An error with additional context attached

Fields

context: String
error: Box<Self>


Directory(Error)

Error creating the parent directory of the DB file



Migrate(Error)

Error applying migrations to the DBs



Path

Error getting the path for a collection file

Fields

path: PathBuf
error: Error


ResourceUnknown

Queried for some resource by a unique identifier, but it wasn’t found in the DB

Fields

kind: &'static str


Sqlite(Error)

Any SQL error. Generally this should be wrapped in a Self::Context

Implementations

Source

impl DatabaseError

pub fn add_context<Ctx, E>(context: Ctx) -> impl FnOnce(E) -> Self
where Ctx: Into<String>, E: Into<Self>,

Create a function that will attach the given context to an error. Convenient to pass to Result::map_err.

pub fn with_context<Ctx, E>(error: E, context: Ctx) -> Self
where Ctx: Into<String>, E: Into<Self>,

Attach context to an error error