pub enum TriggeredRequestError {
NotAllowed,
Build(Arc<RequestBuildError>),
Send(Arc<RequestError>),
}Expand description
Error occurred while trying to build/execute a triggered request.
This type implements Clone so it can be shared between deduplicated chain
renders, hence the Arcs on inner errors.
Variants
NotAllowed
This render was invoked in a way that doesn’t support automatic request execution. In some cases the user needs to explicitly opt in to enable it (e.g. with a CLI flag)
Build(Arc<RequestBuildError>)
Tried to auto-execute a chained request but couldn’t build it
Send(Arc<RequestError>)
Chained request was triggered, sent and failed