pub struct Collection {
pub name: Option<String>,
pub profiles: IndexMap<ProfileId, Profile>,
pub recipes: RecipeTree,
}Expand description
A collection of profiles, requests, etc. This is the primary Slumber unit of configuration.
Fields
name: Option<String>Descriptive name for the collection
profiles: IndexMap<ProfileId, Profile>Map of profiles, keyed by their unique IDs
recipes: RecipeTreeMap of requests and folders, keyed by their unique IDs. Folders allow for nested maps of more requests and folders. All IDs must be unique throughout the entire tree, not just at their level.
Implementations
Sourceimpl Collection
impl Collection
Sourcepub fn load(path: &Path) -> Result<Self, CollectionError>
pub fn load(path: &Path) -> Result<Self, CollectionError>
Load collection from a file
Sourcepub fn parse(input: &str) -> Result<Self, CollectionError>
pub fn parse(input: &str) -> Result<Self, CollectionError>
Load collection from a YAML string
Sourceimpl Collection
impl Collection
Sourcepub fn default_profile(&self) -> Option<&Profile>
pub fn default_profile(&self) -> Option<&Profile>
Get the profile marked as default: true, if any. At most one profile
can be marked as default.