pub enum DatabaseError {
Context {
context: String,
error: Box<Self>,
},
Directory(Error),
Migrate(Error),
Path {
path: PathBuf,
error: Error,
},
ResourceUnknown {
kind: &'static str,
id: String,
},
Sqlite(Error),
}Expand description
Any error that can occur while accessing the local database
Variants
Context
An error with additional context attached
Directory(Error)
Error creating the parent directory of the DB file
Migrate(Error)
Error applying migrations to the DBs
Path
Error getting the path for a collection file
ResourceUnknown
Queried for some resource by a unique identifier, but it wasn’t found in the DB
Sqlite(Error)
Any SQL error. Generally this should be wrapped in a Self::Context
Implementations
Sourceimpl DatabaseError
impl DatabaseError
Sourcepub fn add_context<Ctx, E>(context: Ctx) -> impl FnOnce(E) -> Self
pub fn add_context<Ctx, E>(context: Ctx) -> impl FnOnce(E) -> Self
Create a function that will attach the given context to an error. Convenient to pass to Result::map_err.
Sourcepub fn with_context<Ctx, E>(error: E, context: Ctx) -> Self
pub fn with_context<Ctx, E>(error: E, context: Ctx) -> Self
Attach context to an error error