pub enum RequestBuildErrorKind {
Show 19 variants
AuthPasswordRender(RenderError),
AuthTokenRender(RenderError),
AuthUsernameRender(RenderError),
BodyFileStream(Error),
BodyFormFieldRender {
field: String,
error: RenderError,
},
BodyMissing {
previous_request_id: RequestId,
},
BodyRender(RenderError),
BodyStream(RenderError),
Build(Error),
CurlInvalidUtf8(Utf8Error),
HeaderInvalidName {
header: String,
error: InvalidHeaderName,
},
HeaderInvalidValue {
header: String,
error: InvalidHeaderValue,
},
HeaderRender {
header: String,
error: RenderError,
},
Json(JsonTemplateError),
OverrideFormBody,
QueryRender {
parameter: String,
error: RenderError,
},
RecipeUnknown(UnknownRecipeError),
UrlInvalid {
url: String,
error: ParseError,
},
UrlRender(RenderError),
}Expand description
The various errors that can occur while building a request. This provides the error for RequestBuildError, which then attaches additional context.
Variants
AuthPasswordRender(RenderError)
Error rendering username in Basic auth
AuthTokenRender(RenderError)
Error rendering token in Bearer auth
AuthUsernameRender(RenderError)
Error rendering username in Basic auth
BodyFileStream(Error)
Error streaming directly from a file to a request body (via reqwest)
BodyFormFieldRender
Error rendering a body to bytes/stream
BodyMissing
Attempted to build a new request from a previous request, but the old request doesn’t have a body saved
This happens if:
- Body was larger than
HttpEngineConfig::large_body_size - Body was streamed
BodyRender(RenderError)
Error rendering a body to bytes/stream
BodyStream(RenderError)
Error while streaming bytes for a body
Build(Error)
Error assembling the final request
CurlInvalidUtf8(Utf8Error)
Attempted to generate a cURL command for a request with non-UTF-8 values, which we don’t support representing in the generated command
HeaderInvalidName
Header name does not meet the HTTP spec
HeaderInvalidValue
Header name does not meet the HTTP spec
HeaderRender
Header value does not meet the HTTP spec
Json(JsonTemplateError)
Error parsing JSON override template
OverrideFormBody
Passed a full-body override template for a form body. This is disallowed; instead, overrides are applied by individual field
QueryRender
Error rendering query parameter
RecipeUnknown(UnknownRecipeError)
Tried to build a recipe that doesn’t exist
UrlInvalid
URL rendered correctly but the result isn’t a valid URL
UrlRender(RenderError)
Error rendering URL