pub struct HttpEngine { /* private fields */ }Expand description
Utility for handling all HTTP operations. The main purpose of this is to de-asyncify HTTP so it can be called in the main TUI thread. All heavy lifting will be pushed to background tasks.
This is safe and cheap to clone because reqwest’s Client type uses Arc
internally. reqwest::Client
Implementations
Sourceimpl HttpEngine
impl HttpEngine
Sourcepub fn new(config: &HttpEngineConfig) -> Self
pub fn new(config: &HttpEngineConfig) -> Self
Build a new HTTP engine, which can be used for the entire program life
Sourcepub async fn build(
&self,
seed: RequestSeed,
context: &TemplateContext,
) -> Result<RequestTicket, RequestBuildError>
pub async fn build( &self, seed: RequestSeed, context: &TemplateContext, ) -> Result<RequestTicket, RequestBuildError>
Build a RequestTicket from a RequestSeed. This will render the recipe into a request. The returned ticket can then be launched.
Sourcepub fn rebuild(
&self,
previous_request: &RequestRecord,
) -> Result<RequestTicket, RequestBuildError>
pub fn rebuild( &self, previous_request: &RequestRecord, ) -> Result<RequestTicket, RequestBuildError>
Build a RequestTicket from a past RequestRecord
This will fail only if the body was not saved from the previous request. This happens if:
- Body was larger than HttpEngineConfig::large_body_size
- Body was streamed
Sourcepub async fn build_url(
&self,
seed: RequestSeed,
context: &TemplateContext,
) -> Result<Url, RequestBuildError>
pub async fn build_url( &self, seed: RequestSeed, context: &TemplateContext, ) -> Result<Url, RequestBuildError>
Render just the URL of a request, including query parameters
Sourcepub async fn build_body(
&self,
seed: RequestSeed,
context: &TemplateContext,
) -> Result<Option<Bytes>, RequestBuildError>
pub async fn build_body( &self, seed: RequestSeed, context: &TemplateContext, ) -> Result<Option<Bytes>, RequestBuildError>
Render just the body of a request
Sourcepub async fn build_curl(
&self,
seed: RequestSeed,
context: &TemplateContext,
) -> Result<String, RequestBuildError>
pub async fn build_curl( &self, seed: RequestSeed, context: &TemplateContext, ) -> Result<String, RequestBuildError>
Render a recipe into a cURL command that will execute the request.
Only fails if a header value or body is binary. We can’t represent binary values in the command, so we’d have to push them to a temp file and have curl extract from there. It’s possible, I just haven’t done it yet.